summaryrefslogtreecommitdiffstats
path: root/libkdepim/progressdialog.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'libkdepim/progressdialog.cpp')
-rw-r--r--libkdepim/progressdialog.cpp70
1 files changed, 35 insertions, 35 deletions
diff --git a/libkdepim/progressdialog.cpp b/libkdepim/progressdialog.cpp
index 8c0ab889..2788afe2 100644
--- a/libkdepim/progressdialog.cpp
+++ b/libkdepim/progressdialog.cpp
@@ -19,11 +19,11 @@
*
* In addition, as a special exception, the copyright holders give
* permission to link the code of this program with any edition of
- * the Qt library by Trolltech AS, Norway (or with modified versions
- * of Qt that use the same license as Qt), and distribute linked
+ * the TQt library by Trolltech AS, Norway (or with modified versions
+ * of TQt that use the same license as TQt), and distribute linked
* combinations including the two. You must obey the GNU General
* Public License in all respects for all of the code used other than
- * Qt. If you modify this file, you may extend this exception to
+ * TQt. If you modify this file, you may extend this exception to
* your version of the file, but you are not obligated to do so. If
* you do not wish to do so, delete this exception statement from
* your version.
@@ -60,10 +60,10 @@ namespace KPIM {
class TransactionItem;
-TransactionItemView::TransactionItemView( TQWidget * parent,
+TransactionItemView::TransactionItemView( TQWidget * tqparent,
const char * name,
WFlags f )
- : TQScrollView( parent, name, f ) {
+ : TQScrollView( tqparent, name, f ) {
setFrameStyle( NoFrame );
mBigBox = new TQVBox( viewport() );
mBigBox->setSpacing( 5 );
@@ -84,9 +84,9 @@ void TransactionItemView::resizeContents( int w, int h )
// (handling of TQEvent::LayoutHint in TQScrollView calls this method)
//kdDebug(5300) << k_funcinfo << w << "," << h << endl;
TQScrollView::resizeContents( w, h );
// Tell the tqlayout in the parent (progressdialog) that our size changed
updateGeometry();
// Resize the parent (progressdialog) - this works but resize horizontally too often
//tqparentWidget()->adjustSize();
TQApplication::sendPostedEvents( 0, TQEvent::ChildInserted );
@@ -112,8 +112,8 @@ TQSize TransactionItemView::tqminimumSizeHint() const
int minw = tqtopLevelWidget()->width() / 3;
int maxh = tqtopLevelWidget()->height() / 2;
TQSize sz( mBigBox->tqminimumSizeHint() );
- sz.setWidth( QMAX( sz.width(), minw ) + f + vsbExt );
- sz.setHeight( QMIN( sz.height(), maxh ) + f );
+ sz.setWidth( TQMAX( sz.width(), minw ) + f + vsbExt );
+ sz.setHeight( TQMIN( sz.height(), maxh ) + f );
return sz;
}
@@ -121,7 +121,7 @@ TQSize TransactionItemView::tqminimumSizeHint() const
void TransactionItemView::slotLayoutFirstItem()
{
/*
- The below relies on some details in Qt's behaviour regarding deleting
+ The below relies on some details in TQt's behaviour regarding deleting
objects. This slot is called from the destroyed signal of an item just
going away. That item is at that point still in the list of chilren, but
since the vtable is already gone, it will have type TQObject. The first
@@ -139,9 +139,9 @@ void TransactionItemView::slotLayoutFirstItem()
// ----------------------------------------------------------------------------
-TransactionItem::TransactionItem( TQWidget* parent,
+TransactionItem::TransactionItem( TQWidget* tqparent,
ProgressItem *item, bool first )
- : TQVBox( parent, "TransactionItem" ), mCancelButton( 0 ), mItem( item )
+ : TQVBox( tqparent, "TransactionItem" ), mCancelButton( 0 ), mItem( item )
{
setSpacing( 2 );
@@ -159,15 +159,15 @@ TransactionItem::TransactionItem( TQWidget* parent,
mItemLabel = new TQLabel( item->label(), h );
// always interpret the label text as RichText, but disable word wrapping
- mItemLabel->setTextFormat( Qt::RichText );
- mItemLabel->tqsetAlignment( Qt::AlignAuto | Qt::AlignVCenter | Qt::SingleLine );
+ mItemLabel->setTextFormat( TQt::RichText );
+ mItemLabel->tqsetAlignment( TQt::AlignAuto | TQt::AlignVCenter | TQt::SingleLine );
h->tqsetSizePolicy( TQSizePolicy( TQSizePolicy::Preferred, TQSizePolicy::Fixed ) );
mProgress = new TQProgressBar( 100, h );
mProgress->setProgress( item->progress() );
if ( item->canBeCanceled() ) {
- mCancelButton = new TQPushButton( SmallIcon( "cancel" ), TQString::null, h );
+ mCancelButton = new TQPushButton( SmallIcon( "cancel" ), TQString(), h );
TQToolTip::add( mCancelButton, i18n("Cancel this operation.") );
connect ( mCancelButton, TQT_SIGNAL( clicked() ),
this, TQT_SLOT( slotItemCanceled() ));
@@ -178,14 +178,14 @@ TransactionItem::TransactionItem( TQWidget* parent,
h->tqsetSizePolicy( TQSizePolicy( TQSizePolicy::Preferred, TQSizePolicy::Fixed ) );
mSSLLabel = new SSLLabel( h );
mSSLLabel->tqsetSizePolicy( TQSizePolicy( TQSizePolicy::Fixed, TQSizePolicy::Fixed ) );
- mItemStatus = new TQLabel( item->status(), h );
+ mItemtqStatus = new TQLabel( item->status(), h );
// always interpret the status text as RichText, but disable word wrapping
- mItemStatus->setTextFormat( Qt::RichText );
- mItemStatus->tqsetAlignment( Qt::AlignAuto | Qt::AlignVCenter | Qt::SingleLine );
+ mItemtqStatus->setTextFormat( TQt::RichText );
+ mItemtqStatus->tqsetAlignment( TQt::AlignAuto | TQt::AlignVCenter | TQt::SingleLine );
// richtext leads to tqsizeHint acting as if wrapping was enabled though,
// so make sure we only ever have the height of one line.
- mItemStatus->tqsetSizePolicy( TQSizePolicy( TQSizePolicy::Preferred, TQSizePolicy::Ignored ) );
- mItemStatus->setFixedHeight( mItemLabel->tqsizeHint().height() );
+ mItemtqStatus->tqsetSizePolicy( TQSizePolicy( TQSizePolicy::Preferred, TQSizePolicy::Ignored ) );
+ mItemtqStatus->setFixedHeight( mItemLabel->tqsizeHint().height() );
setCrypto( item->usesCrypto() );
if( first ) hideHLine();
}
@@ -209,9 +209,9 @@ void TransactionItem::setLabel( const TQString& label )
mItemLabel->setText( label );
}
-void TransactionItem::seStatus( const TQString& status )
+void TransactionItem::setqStatus( const TQString& status )
{
- mItemStatus->setText( status );
+ mItemtqStatus->setText( status );
}
void TransactionItem::setCrypto( bool on )
@@ -244,11 +244,11 @@ void TransactionItem::addSubTransaction( ProgressItem* /*item*/ )
// ---------------------------------------------------------------------------
-ProgressDialog::ProgressDialog( TQWidget* alignWidget, TQWidget* parent, const char* name )
- : OverlayWidget( alignWidget, parent, name ), mWasLastShown( false )
+ProgressDialog::ProgressDialog( TQWidget* alignWidget, TQWidget* tqparent, const char* name )
+ : OverlayWidget( alignWidget, tqparent, name ), mWasLastShown( false )
{
- setFrameStyle( TQFrame::Panel | TQFrame::Sunken ); // QFrame
- setSpacing( 0 ); // QHBox
+ setFrameStyle( TQFrame::Panel | TQFrame::Sunken ); // TQFrame
+ setSpacing( 0 ); // TQHBox
setMargin( 1 );
mScrollView = new TransactionItemView( this, "ProgressScrollView" );
@@ -278,8 +278,8 @@ ProgressDialog::ProgressDialog( TQWidget* alignWidget, TQWidget* parent, const c
this, TQT_SLOT( slotTransactionCompleted( KPIM::ProgressItem* ) ) );
connect ( pm, TQT_SIGNAL( progressItemProgress( KPIM::ProgressItem*, unsigned int ) ),
this, TQT_SLOT( slotTransactionProgress( KPIM::ProgressItem*, unsigned int ) ) );
- connect ( pm, TQT_SIGNAL( progressItemStatus( KPIM::ProgressItem*, const TQString& ) ),
- this, TQT_SLOT( slotTransactionStatus( KPIM::ProgressItem*, const TQString& ) ) );
+ connect ( pm, TQT_SIGNAL( progressItemtqStatus( KPIM::ProgressItem*, const TQString& ) ),
+ this, TQT_SLOT( slotTransactiontqStatus( KPIM::ProgressItem*, const TQString& ) ) );
connect ( pm, TQT_SIGNAL( progressItemLabel( KPIM::ProgressItem*, const TQString& ) ),
this, TQT_SLOT( slotTransactionLabel( KPIM::ProgressItem*, const TQString& ) ) );
connect ( pm, TQT_SIGNAL( progressItemUsesCrypto(KPIM::ProgressItem*, bool) ),
@@ -307,11 +307,11 @@ ProgressDialog::~ProgressDialog()
void ProgressDialog::slotTransactionAdded( ProgressItem *item )
{
- TransactionItem *parent = 0;
- if ( item->parent() ) {
- if ( mTransactionsToListviewItems.tqcontains( item->parent() ) ) {
- parent = mTransactionsToListviewItems[ item->parent() ];
- parent->addSubTransaction( item );
+ TransactionItem *tqparent = 0;
+ if ( item->tqparent() ) {
+ if ( mTransactionsToListviewItems.tqcontains( item->tqparent() ) ) {
+ tqparent = mTransactionsToListviewItems[ item->tqparent() ];
+ tqparent->addSubTransaction( item );
}
} else {
const bool first = mTransactionsToListviewItems.empty();
@@ -353,12 +353,12 @@ void ProgressDialog::slotTransactionProgress( ProgressItem *item,
}
}
-void ProgressDialog::slotTransactionStatus( ProgressItem *item,
+void ProgressDialog::slotTransactiontqStatus( ProgressItem *item,
const TQString& status )
{
if ( mTransactionsToListviewItems.tqcontains( item ) ) {
TransactionItem *ti = mTransactionsToListviewItems[ item ];
- ti->seStatus( status );
+ ti->setqStatus( status );
}
}
@@ -84,9 +84,9 @@ void TransactionItemView::resizeContents( int w, int h )
//kdDebug(5300) << k_funcinfo << w << "," << h << endl;
TQScrollView::resizeContents( w, h );
- // Tell the tqlayout in the parent (progressdialog) that our size changed
+ // Tell the tqlayout in the tqparent (progressdialog) that our size changed
updateGeometry();
@@ -84,9 +84,9 @@ void TransactionItemView::resizeContents( int w, int h )
updateGeometry();
- // Resize the parent (progressdialog) - this works but resize horizontally too often
+ // Resize the tqparent (progressdialog) - this works but resize horizontally too often
//tqparentWidget()->adjustSize();
TQApplication::sendPostedEvents( 0, TQEvent::ChildInserted );